# {{ cookiecutter.project_name }}

## What is it?
{{ cookiecutter.project_name }} is ...

[![Issues](https://img.shields.io/github/issues/{{ cookiecutter.github_username }}/{{ cookiecutter.project_slug }})](https://github.com/{{ cookiecutter.github_username }}/{{ cookiecutter.project_slug }}/issues)
[![License](https://img.shields.io/github/license/{{ cookiecutter.github_username }}/{{ cookiecutter.project_slug }})](LICENSE)
[![Version](https://img.shields.io/pypi/v/{{ cookiecutter.project_slug }}?color=brightgreen)](https://pypi.org/project/{{ cookiecutter.project_slug }}/)

## Table of Contents
* [Key features](#key-features)
* [Installation](#installation)
* [Quickstart](#quickstart)
* [Contributing](#contributing)
* [Blog posts](#blog-posts)
* [Documentation](#documentation)
* [License](#license)
* [Support](#support)

---

## :key: Key features <a name="key-features"></a>

---

## :computer: Installation <a name="installation"></a>

### pip
Install the latest stable release from PyPI using
```shell
$ pip3 install {{ cookiecutter.project_name }}

```

or clone the development version from GitHub with
```shell
$ git clone https://github.com/{{ cookiecutter.github_username }}/{{ cookiecutter.project_slug }}.git
```

---

## :seedling: Quickstart <a name="quickstart"></a>

{{ cookiecutter.project_name }} is designed to be ...

---

## :pray: Contributing <a name="contributing"></a>
All contributions, bug reports, bug fixes, documentation improvements, enhancements, and ideas are welcome!

Feel free to [open an Issue](https://github.com/{{ cookiecutter.github_username }}/{{ cookiecutter.project_slug }}/issues/new/choose), check out existing [Issues](https://github.com/{{ cookiecutter.github_username }}/{{ cookiecutter.project_slug }}/issues), or [start a discussion](https://github.com/{{ cookiecutter.github_username }}/{{ cookiecutter.project_slug }}/discussions).

Beginners to open source are highly encouraged to participate and ask questions if you're unsure what to do/where to start

---

## :newspaper: Blog posts <a name="blog-posts"></a>
Check out the [official website](https://{{ cookiecutter.github_username }}.github.io/{{ cookiecutter.project_slug }}/) for the latest blog posts on the project!

---

## :books: Documentation <a name="documentation"></a>
<!-- The official documentation can be found on [Read The Docs](https://{{ cookiecutter.project_slug }}.readthedocs.io/en/latest/index.html) -->

---

## :credit_card: License <a name="license"></a>
This library operates under the [MIT](LICENSE) license.

---

## :grey_question: Support <a name="support"></a>
